UTA is a data archive and set of tools that aims to improve the precision
of sequence-based descriptions of genomic variation.  It will eventually
contain transcripts and alignments to multiple reference genomes using
multiple algorithms, as obtained from from `NCBI`_, `Ensembl`_, `LRG`_,
and `UCSC`_.

.. _NCBI: http://www.ncbi.nlm.nih.gov/
.. _Ensembl: http://ensembl.org
.. _LRG: http://www.lrg-sequence.org/
.. _UCSC: http://genome.ucsc.edu/
